package p;

public class TestTextBlock {
	public void foo() {
			String x = 
				"""
				This is a text block
				   with an indent
				""";
	}
}